//
//  QtsHttpSystem.h
//  QTSHTTPSDK
//
//  Created by Lawrence on 2013/11/24.
//  Copyright (c) 2013年 Lawrence. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "QtsHttpComm.h"

/** QTS HTTP system map to SDK version. */
typedef enum _QTS_HTTP_SYSTEM_API_VERSION_
{
	/** Unknow version */
	QTS_HTTP_SYSTEM_API_VERSION_UNKNOW = 0,
	/** QTS HTTP system API Version 1 */
	QTS_HTTP_SYSTEM_API_V1   = 1,
	//QTS_HTTP_SYSTEM_API_V2 = 2,
}QTS_HTTP_SYSTEM_API_VERSION;

/*!
 * \brief
 * QTS system setting information class
 *
 */
@interface QNSystemSettingInfo : NSObject
{
    NSString*   serverName;
    long        serverPort;
    BOOL        isSSL;
    long        serverSSLPort;
    BOOL        isForceSSL;
}

@property (strong) NSString*   serverName;      /** QNAP Turbo NAS server name */
@property (assign) long        serverPort;      /** System port number */
@property (assign) BOOL        isSSL;           /** Enable SSL or not */
@property (assign) long        serverSSLPort;   /** SSL port number */
@property (assign) BOOL        isForceSSL;      /** Force use SSL or not */

@end

/*!
 * \brief
 * Interface for Qts Http system API
 *
 * 1. Support system related API.
 */
@protocol IQtsHttpSystem <NSObject>
@optional

/*!
 * \brief
 * Get system setting of QNAP Turbo NAS.
 *
 * [IN] isAsync : Execute API by Synchronized or Asynchronized Mode.
 * \param
 * [IN] isCancel : Cancel API.
 * \param
 * [BLOCK] success : block to retrieve QTS_RESPONSE_CTX class when API was executed successfully.
 *                   QTS_RESPONSE_CTX's response will store QNSystemSettingInfo class.
 * \param
 * [BLOCK] fail : block to retrieve error code when API was executed failurely.
 *
 * \returns
 * n/a.
 */
-(void) getSystemSettingWithCommunicationMode:(BOOL)isAsync cancel:(int*)isCancel success:(void(^)(QTS_RESPONSE_CTX* response))success fail:(void(^)(QTS_HTTP_API_RESULTS error))fail;
/*!
 * \brief
 * Enable file station service of QNAP Turbo NAS.
 *
 * [IN] isAsync : Execute API by Synchronized or Asynchronized Mode.
 * \param
 * [IN] isCancel : Cancel API.
 * \param
 * [BLOCK] success : block to retrieve QTS_RESPONSE_CTX class when API was executed successfully.
 *                   QTS_RESPONSE_CTX's response will store QNSystemSettingInfo class.
 * \param
 * [BLOCK] fail : block to retrieve error code when API was executed failurely.
 *
 * \returns
 * n/a.
 */
-(void) enableFileStationWithCommunicationMode:(BOOL)isAsync cancel:(int*)isCancel success:(void(^)(QTS_RESPONSE_CTX* response))success fail:(void(^)(QTS_HTTP_API_RESULTS error))fail;

@end
@interface QNQtsHttpSystem : NSObject <IQtsHttpSystem>
@end

