//
//  DocumentFolderListViewController.m
//  iOS_QtsHttp_SDK_Sample
//
//  Created by Lawrence on 2013/11/28.
//  Copyright (c) 2013年 Lawrence. All rights reserved.
//

#import "DocumentFolderListViewController.h"

@interface DocumentFolderListViewController ()
{
    UIAlertView* altProgress;
}
@end
@implementation DocumentFolderListViewController
@synthesize destFilePath,isUpload;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        list = [[NSMutableArray alloc] init];
        destFilePath = @"";
        isUpload = NO;
        
        server = [(AppDelegate*)[[UIApplication sharedApplication] delegate] getServer];
        
        altProgress = [[UIAlertView alloc] initWithTitle:@"Upload Progress" message:@"" delegate:self cancelButtonTitle:@"STOP" otherButtonTitles:nil, nil];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    [self getDocumentList];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void)getDocumentList
{
    [list removeAllObjects];
    // Obtain File List of Document folder in sandbox
    NSString * resourcePath = [[NSBundle mainBundle] resourcePath];
    resourcePath = [resourcePath stringByReplacingOccurrencesOfString:[resourcePath lastPathComponent] withString:@""];
    NSString * documentsPath = [resourcePath stringByAppendingPathComponent:@"Documents"];
    NSError * error;
    NSArray * directoryContents = [[NSFileManager defaultManager] contentsOfDirectoryAtPath:documentsPath error:&error];
    for ( id item in directoryContents )
    {
        BOOL isDir = YES;
        NSString* name = [NSString stringWithFormat:@"%@",item];
        if ( [name rangeOfString:@"."].location == NSNotFound ){
            isDir = YES;
        }
        else{
            isDir = NO;
        }
        
        QNQtsHttpFileEntry* entry = [[QNQtsHttpFileEntry alloc] initWithPath:documentsPath name:item size:0 isDir:isDir];
        [list addObject:entry];
    }
    
    [tblList reloadData];
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [list count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
    }
    
    QNQtsHttpFileEntry* item = [list objectAtIndex:indexPath.row];
    cell.textLabel.text = item.name;
    cell.detailTextLabel.text = item.path;
    
    [cell setBackgroundColor:[UIColor blackColor]];
    [cell.textLabel setTextColor:[UIColor whiteColor]];
    [cell.detailTextLabel setTextColor:[UIColor whiteColor]];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    QNQtsHttpFileEntry* item = [list objectAtIndex:indexPath.row];
    
    if ( !item.isDir ) {
        isAbort = 0;
        [altProgress show];
        NSLog(@"Upload from: %@, to: %@", [NSString stringWithFormat:@"%@/%@",item.path,item.name], destFilePath);
        [[server openFileStation] uploadFileWithPath:[NSString stringWithFormat:@"%@/%@",item.path,item.name] toPath:destFilePath communicationMode:YES cancel:&isAbort
        success:^(QTS_RESPONSE_CTX *response) {
            if ( response.result == QTS_HTTP_APIS_SUCCESS ) {
                [self.navigationController popViewControllerAnimated:YES];
                NSLog(@"UPLOAD FILE DONE.");
                [self stopShowProgress];
            }
        } fail:^(QTS_HTTP_API_RESULTS error) {
            NSLog(@"UPLOAD FILE FAIL.(ErrorCode=%d)",error);
            [self stopShowProgress];
        } progress:^(int progress, unsigned long long byteofTransfered) {
            NSLog(@"UPLOAD FILE: %d%%", progress);
        }];
    }
}

- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex
{
    isAbort = 1;
}

- (void)showProgress
{
    if ([NSThread isMainThread])
        [self threadShowProgress];
    else
        [self performSelectorOnMainThread:@selector(threadShowProgress) withObject:nil waitUntilDone:NO];
}

- (void)stopShowProgress
{
    if ([NSThread isMainThread])
        [self threadStopShowProgress];
    else
        [self performSelectorOnMainThread:@selector(threadStopShowProgress) withObject:nil waitUntilDone:NO];
}

- (void)threadShowProgress
{
    [altProgress show];
}

- (void)threadStopShowProgress
{
    [altProgress dismissWithClickedButtonIndex:-1 animated:YES];
}

@end
