//
//  DownloadViewController.m
//  iOS_QtsHttp_SDK_Sample
//
//  Created by Lawrence on 2013/11/28.
//  Copyright (c) 2013年 Lawrence. All rights reserved.
//

#import "DownloadViewController.h"
#import "DocumentFolderListViewController.h"

@interface DownloadViewController ()
{
    UIAlertView* altProgress;
}
@end

@implementation DownloadViewController
@synthesize currentLocationPath;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        list = [[NSMutableArray alloc] init];
        isAbort = 0;
        server = [(AppDelegate*)[[UIApplication sharedApplication] delegate] getServer];
        altProgress = [[UIAlertView alloc] initWithTitle:@"Download Progress" message:@"" delegate:self cancelButtonTitle:@"STOP" otherButtonTitles:nil, nil];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    if ( [currentLocationPath isEqualToString:@"share_root"] ) {
        [self getFolderList];
    }
    else {
        [self getFileList:currentLocationPath];
    }
    
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [list count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
    }
    
    if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileStatus class]] ) {
        QNQtsHttpFileStatus* item = [list objectAtIndex:indexPath.row];
        cell.textLabel.text = item.name;
        cell.detailTextLabel.text = item.path;
    }
    else if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileEntry class]] ) {
        QNQtsHttpFileEntry* item = [list objectAtIndex:indexPath.row];
        cell.textLabel.text = item.name;
        cell.detailTextLabel.text = item.path;
    }
    
    if ( [currentLocationPath isEqualToString:@"share_root"] ) {
        cell.detailTextLabel.text = @"share_root";
    }
    
    [cell setBackgroundColor:[UIColor blackColor]];
    [cell.textLabel setTextColor:[UIColor whiteColor]];
    [cell.detailTextLabel setTextColor:[UIColor whiteColor]];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileStatus class]] ) {
        QNQtsHttpFileStatus* item = [list objectAtIndex:indexPath.row];
        if ( item.isDir ) {
            DownloadViewController* view = [[DownloadViewController alloc] initWithNibName:@"DownloadViewController" bundle:nil];
            view.currentLocationPath = [NSString stringWithFormat:@"%@/%@", item.path, item.name];
            [self.navigationController pushViewController:view animated:YES];
        }
        else {
            NSThread *thread = [[NSThread alloc] initWithTarget:self selector:@selector(download:) object:item];
            [thread start];
        }
    }
    else if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileEntry class]] ) {
        QNQtsHttpFileEntry* item = [list objectAtIndex:indexPath.row];
        if ( item.isDir ) {
            DownloadViewController* view = [[DownloadViewController alloc] initWithNibName:@"DownloadViewController" bundle:nil];
            view.currentLocationPath = [NSString stringWithFormat:@"/%@", item.name];
            [self.navigationController pushViewController:view animated:YES];
        }
        else {
            NSThread *thread = [[NSThread alloc] initWithTarget:self selector:@selector(download:) object:item];
            [thread start];
        }
    }
}

-(void) download:(id)file
{
    if ( [file isKindOfClass:[QNQtsHttpFileStatus class]] ) {
        QNQtsHttpFileStatus* item = (QNQtsHttpFileStatus*)file;
        QNQtsHttpFileEntry* entry = [[QNQtsHttpFileEntry alloc] initWithPath:item.path name:item.name size:item.size isDir:item.isDir];
        
        NSString* resourcePath = [[NSBundle mainBundle] resourcePath];
        resourcePath = [resourcePath stringByReplacingOccurrencesOfString:[resourcePath lastPathComponent] withString:@""];
        NSString* documentsPath = [resourcePath stringByAppendingPathComponent:@"Documents"];
        NSFileManager *fileManger = [NSFileManager defaultManager];
        BOOL isDir = NO;
        if (![fileManger fileExistsAtPath:documentsPath isDirectory:&isDir])
        {
            [fileManger createDirectoryAtPath:documentsPath withIntermediateDirectories:YES attributes:nil error:nil];
        }
        
        isAbort = 0;
        [self showProgress];
        [[server openFileStation] downloadFile:entry toPath:documentsPath offset:0 communicationMode:YES cancel:&isAbort
                                       success:^(QTS_RESPONSE_CTX *response) {
                                           if ( response.result == QTS_HTTP_APIS_SUCCESS ) {
                                               NSLog(@"DOWNLOAD FILE DONE.");
                                               [self getLocalFileList];
                                               [self stopShowProgress];
                                           }
                                       } fail:^(QTS_HTTP_API_RESULTS error) {
                                           NSLog(@"DOWNLOAD FILE FAIL.(ErrorCode=%d)",error);
                                           [self stopShowProgress];
                                       } progress:^(int progress, unsigned long long byteofTransfered) {
                                           NSLog(@"DOWNLOAD FILE: %d%%", progress);
                                       }];

    }
}

-(void)getLocalFileList
{
    DocumentFolderListViewController* view = [[DocumentFolderListViewController alloc] initWithNibName:@"DocumentFolderListViewController" bundle:nil];
    [self.navigationController pushViewController:view animated:YES];
}

-(void)getFolderList
{
    isAbort = 0;
    [[server openFileStation] getShareFolderListWithCommunicationMode:YES cancel:&isAbort
                                                              success:^(QTS_RESPONSE_CTX *response) {
                                                                  [list removeAllObjects];
                                                                  list = (NSMutableArray*)response.response;
                                                                  [tblFileList reloadData];
                                                              } fail:^(QTS_HTTP_API_RESULTS error) {
                                                                  NSLog(@"GET SHARE FOLDER LIST FAIL.");
                                                              }];
}

-(void)getFileList:(NSString*)path
{
    @synchronized( list )
    {
        isAbort = 0;
        [[server openFileStation] getFileListCountWithPath:path communicationMode:YES cancel:&isAbort
                                                   success:^(QTS_RESPONSE_CTX *response) {
                                                       int total = [[[response.response objectAtIndex:0] objectForKey:@"count"] intValue];
                                                       [list removeAllObjects];
                                                       for ( int idx = 0 ; idx < total ;  idx = (idx+1000) )
                                                       {
                                                           [[server openFileStation] getFileListWithPath:path indexFrom:idx fileLimit:1000 communicationMode:YES cancel:&isAbort success:^(QTS_RESPONSE_CTX *response) {
                                                                    for ( QNQtsHttpFileStatus* item in response.response ) {
                                                                        [list addObject:item];
                                                                    }
                                                                    [tblFileList reloadData];
                                                                } fail:^(QTS_HTTP_API_RESULTS error) {
                                                                NSLog(@"GET FILE LIST FAIL.");
                                                            }];
                                                       }
                                                   } fail:^(QTS_HTTP_API_RESULTS error) {
                                                       NSLog(@"GET FILE LIST COUNT FAIL.");
                                                   }];
    }
}

- (void)alertView:(UIAlertView *)alertView clickedButtonAtIndex:(NSInteger)buttonIndex
{
    isAbort = 1;
}

- (void)showProgress
{
    if ([NSThread isMainThread])
        [self threadShowProgress];
    else
        [self performSelectorOnMainThread:@selector(threadShowProgress) withObject:nil waitUntilDone:NO];
}

- (void)stopShowProgress
{
    if ([NSThread isMainThread])
        [self threadStopShowProgress];
    else
        [self performSelectorOnMainThread:@selector(threadStopShowProgress) withObject:nil waitUntilDone:NO];
}

- (void)threadShowProgress
{
    [altProgress show];
}

- (void)threadStopShowProgress
{
    [altProgress dismissWithClickedButtonIndex:-1 animated:YES];
}

@end
