//
//  UploadViewController.m
//  iOS_QtsHttp_SDK_Sample
//
//  Created by Lawrence on 2013/11/28.
//  Copyright (c) 2013年 Lawrence. All rights reserved.
//

#import "UploadViewController.h"
#import "DocumentFolderListViewController.h"

@interface UploadViewController ()

@end

@implementation UploadViewController
@synthesize currentLocationPath;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        list = [[NSMutableArray alloc] init];
        isAbort = 0;
        server = [(AppDelegate*)[[UIApplication sharedApplication] delegate] getServer];
        
        UIBarButtonItem *DemoButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAdd target:self action:@selector(showLocalFileList)];
        self.navigationItem.rightBarButtonItem = DemoButton;
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    // Do any additional setup after loading the view from its nib.
    if ( [currentLocationPath isEqualToString:@"share_root"] ) {
        [self getFolderList];
    }
    else {
        [self getFileList:currentLocationPath];
    }
}

-(void)viewWillAppear:(BOOL)animated
{
    if ( [currentLocationPath isEqualToString:@"share_root"] ) {
        [self getFolderList];
    }
    else {
        [self getFileList:currentLocationPath];
    }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [list count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
    }
    
    if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileStatus class]] ) {
        QNQtsHttpFileStatus* item = [list objectAtIndex:indexPath.row];
        cell.textLabel.text = item.name;
        cell.detailTextLabel.text = item.path;
    }
    else if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileEntry class]] ) {
        QNQtsHttpFileEntry* item = [list objectAtIndex:indexPath.row];
        cell.textLabel.text = item.name;
        cell.detailTextLabel.text = item.path;
    }
    
    if ( [currentLocationPath isEqualToString:@"share_root"] ) {
        cell.detailTextLabel.text = @"share_root";
    }
    
    [cell setBackgroundColor:[UIColor blackColor]];
    [cell.textLabel setTextColor:[UIColor whiteColor]];
    [cell.detailTextLabel setTextColor:[UIColor whiteColor]];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileStatus class]] ) {
        QNQtsHttpFileStatus* item = [list objectAtIndex:indexPath.row];
        if ( item.isDir ) {
            UploadViewController* view = [[UploadViewController alloc] initWithNibName:@"UploadViewController" bundle:nil];
            view.currentLocationPath = [NSString stringWithFormat:@"%@/%@", item.path, item.name];
            [self.navigationController pushViewController:view animated:YES];
        }
    }
    else if ( [[list objectAtIndex:indexPath.row] isKindOfClass:[QNQtsHttpFileEntry class]] ) {
        QNQtsHttpFileEntry* item = [list objectAtIndex:indexPath.row];
        if ( item.isDir ) {
            UploadViewController* view = [[UploadViewController alloc] initWithNibName:@"UploadViewController" bundle:nil];
            view.currentLocationPath = [NSString stringWithFormat:@"/%@", item.name];
            [self.navigationController pushViewController:view animated:YES];
        }
    }
}

-(void)showLocalFileList
{
    DocumentFolderListViewController* view = [[DocumentFolderListViewController alloc] initWithNibName:@"DocumentFolderListViewController" bundle:nil];
    view.destFilePath = currentLocationPath;
    view.isUpload = YES;
    [self.navigationController pushViewController:view animated:YES];
}

-(void)getFolderList
{
    isAbort = 0;
    [[server openFileStation] getShareFolderListWithCommunicationMode:YES cancel:&isAbort
                                                              success:^(QTS_RESPONSE_CTX *response) {
                                                                  [list removeAllObjects];
                                                                  list = (NSMutableArray*)response.response;
                                                                  [tblFileList reloadData];
                                                              } fail:^(QTS_HTTP_API_RESULTS error) {
                                                                  NSLog(@"GET SHARE FOLDER LIST FAIL.");
                                                              }];
}

-(void)getFileList:(NSString*)path
{
    @synchronized( list )
    {
        isAbort = 0;
        [[server openFileStation] getFileListCountWithPath:path communicationMode:YES cancel:&isAbort
                                                   success:^(QTS_RESPONSE_CTX *response) {
                                                       int total = [[[response.response objectAtIndex:0] objectForKey:@"count"] intValue];
                                                       [list removeAllObjects];
                                                       for ( int idx = 0 ; idx < total ;  idx = (idx+1000) )
                                                       {
                                                           [[server openFileStation] getFileListWithPath:path indexFrom:idx fileLimit:1000 communicationMode:YES cancel:&isAbort success:^(QTS_RESPONSE_CTX *response) {
                                                               for ( QNQtsHttpFileStatus* item in response.response ) {
                                                                   [list addObject:item];
                                                               }
                                                               [tblFileList reloadData];
                                                           } fail:^(QTS_HTTP_API_RESULTS error) {
                                                               NSLog(@"GET FILE LIST FAIL.");
                                                           }];
                                                       }
                                                   } fail:^(QTS_HTTP_API_RESULTS error) {
                                                       NSLog(@"GET FILE LIST COUNT FAIL.");
                                                   }];
    }
}
@end
